Reference scanning and fixing for broken file references
This module provides functionality to scan codebases for references to moved/renamed files and generate fixes for those references.
Structs
- Apply
Result - Result of applying fixes
- FixRecord
- Collection of fixes to be applied
- Reference
Fix - A proposed fix for a broken reference
- Reference
Fixer - Applies fixes from a fix record
- Reference
Scanner - Reference scanner for finding broken references after file moves
- Scan
Options - Options for reference scanning